@@ -35,8 +35,8 @@ An array ref of Net::Amazon::EC2::AvailabilityZoneMessage objects representing m
 
 has 'zone_name'		=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'zone_state'	=> ( is => 'ro', isa => 'Str', required => 1 );
-has 'region_name'	=> ( is => 'ro', isa => 'Str', required => 1 );
-has 'messages'		=> ( is => 'ro', isa => 'Maybe[Net::Amazon::EC2::AvailabilityZone]', required => 0 );
+has 'region_name'	=> ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
+has 'messages'		=> ( is => 'ro', isa => 'ArrayRef[Net::Amazon::EC2::AvailabilityZoneMessage]|Undef', required => 0 );
 
 __PACKAGE__->meta->make_immutable();
 
@@ -52,4 +52,4 @@ under the same terms as Perl itself.
 =cut
 
 no Moose;
-1;
\ No newline at end of file
+1;
